.. _kinto-core:

Kinto Core
==========

Kinto-core is the heart of the Kinto projects, and also serves as a handy
toolkit for building Kinto-based backends.

This documentation can also be useful if you want to learn about Kinto internals
like notifications when you write a plugin.

.. toctree::
   :maxdepth: 1

   rationale
   quickstart
   resource
   decorators
   viewsets
   storage
   cache
   notifications
   permission
   errors
   api
   testing
   utils
